@@ -137,12 +137,12 @@
 #' [Analyse_SAR.OSLdata], which works with
 #' [Risoe.BINfileData-class] objects.
 #'
-#' **The function currently does only support 'OSL' or 'IRSL' data!**
+#' **The function currently does support only 'OSL', 'IRSL' and 'POSL' data!**
 #'
-#' @section Function version: 0.8.5
+#' @section Function version: 0.8.7
 #'
 #' @author
-#' Sebastian Kreutzer, IRAMAT-CRP2A, Universite Bordeaux Montaigne (France)
+#' Sebastian Kreutzer, IRAMAT-CRP2A, UMR 5060, Université Bordeaux Montaigne (France)
 #'
 #'
 #' @seealso [calc_OSLLxTxRatio], [plot_GrowthCurve], [RLum.Analysis-class],
@@ -220,7 +220,7 @@ analyse_SAR.CWOSL<- function(
 # SELF CALL -----------------------------------------------------------------------------------
 if(is.list(object)){
 
-  ##make live easy
+  ##make life easy
   if(missing("signal.integral.min")){
     signal.integral.min <- 1
     warning("[analyse_SAR.CWOSL()] 'signal.integral.min' missing, set to 1", call. = FALSE)
@@ -232,10 +232,10 @@ if(is.list(object)){
   }
 
   ##now we have to extend everything to allow list of arguments ... this is just consequent
-  signal.integral.min <- rep(list(signal.integral.min), length = length(object))
-  signal.integral.max <- rep(list(signal.integral.max), length = length(object))
-  background.integral.min <- rep(list(background.integral.min), length = length(object))
-  background.integral.max <- rep(list(background.integral.max), length = length(object))
+  signal.integral.min <- rep(as.list(signal.integral.min), length = length(object))
+  signal.integral.max <- rep(as.list(signal.integral.max), length = length(object))
+  background.integral.min <- rep(as.list(background.integral.min), length = length(object))
+  background.integral.max <- rep(as.list(background.integral.max), length = length(object))
 
 
   ##it is a little bit more complex, as we have a list in a list
@@ -269,11 +269,24 @@ if(is.list(object)){
   }else{
     mtext.outer <- rep(list(""), length = length(object))
 
+  }
+
+  ##handle main
+  if("main"%in% names(list(...))){
+    if(class(list(...)$main) == "list"){
+      main <- rep(list(...)$main,length = length(object))
+
+    }else{
+      main <- rep(as.list(list(...)$main),length = length(object))
+    }
+
+  }else{
+    main <- as.list(paste0("ALQ #",1:length(object)))
+
   }
 
    ##run analysis
    temp <- lapply(1:length(object), function(x){
-
     analyse_SAR.CWOSL(object[[x]],
                       signal.integral.min = signal.integral.min[[x]],
                       signal.integral.max = signal.integral.max[[x]],
@@ -285,7 +298,7 @@ if(is.list(object)){
                       rejection.criteria = rejection.criteria[[x]],
                       plot.single = plot.single,
                       onlyLxTxTable = onlyLxTxTable,
-                      main = ifelse("main"%in% names(list(...)), list(...)$main, paste0("ALQ #",x)),
+                      main = main[[x]],
                       ...)
 
   })
@@ -388,27 +401,23 @@ if(is.list(object)){
     ##INTEGRAL LIMITS
     if(!is(signal.integral, "integer") | !is(background.integral, "integer")){
       stop("[analyse_SAR.CWOSL()] 'signal.integral' or 'background.integral' is not
-           of type integer!")
+           of type integer!",  call. = FALSE)
     }
 
 
 
-      ##CHECK IF DATA SET CONTAINS ANY OSL curve
-      if (!any(grepl("OSL", structure_RLum(object)$recordType)) &&
-          !any(grepl("IRSL", structure_RLum(object)$recordType))) {
-        warning(
-          "[analyse_SAR.CWOSL()] No record of type 'OSL' or 'IRSL' are detected in the sequence object! NULL returned.",
-          call. = FALSE
-        )
-
+    ##CHECK IF DATA SET CONTAINS ANY OSL or IRSL curve
+    if (!any(c(grepl("OSL", names(object), fixed = TRUE), grepl("IRSL", names(object), fixed = TRUE)))){
+        stop("[analyse_SAR.CWOSL()] No record of type 'OSL', 'IRSL', 'POSL' detected! NULL returned.", call. = FALSE)
         return(NULL)
 
-      }
+    }
 
-    ##Check if any OSL curve is measured, if not set curve type on IRSL
-    ##to allow further proceedings
-    CWcurve.type  <- ifelse(!TRUE%in%grepl("OSL", structure_RLum(object)$recordType),
-                            "IRSL","OSL")
+    ##set curve type to allowed type, which is basically an automated curve recognition
+    CWcurve.type <- table(names(object))
+    CWcurve.type <-  CWcurve.type[!grepl("TL", names(CWcurve.type), fixed = TRUE)]
+    CWcurve.type <- names(which.max(CWcurve.type))[1]
+    CWcurve.type <- sub(pattern = " \\(.+", replacement = "", x = CWcurve.type)
 
 
 # Rejection criteria ------------------------------------------------------
@@ -1725,20 +1734,20 @@ if(is.list(object)){
       ##graphical represenation of IR-curve
       temp.IRSL <- suppressWarnings(get_RLum(object, recordType = "IRSL"))
       if(length(temp.IRSL) != 0){
-         if(class(temp.IRSL) == "RLum.Data.Curve"){
-           plot_RLum.Data.Curve(temp.IRSL, par.local = FALSE)
+        if(class(temp.IRSL) == "RLum.Data.Curve"){
+          plot_RLum.Data.Curve(temp.IRSL, par.local = FALSE)
 
-         }else if(class(temp.IRSL) == "list"){
-           plot_RLum.Data.Curve(temp.IRSL[[length(temp.IRSL)]], par.local = FALSE)
-           warning(
-             "[analyse_SAR.CWOSL()] Multiple IRSL curves detected (IRSL test), show only the last one.",
-             immediate. = TRUE,
-             call. = FALSE
-           )
-         }else{
-           shape::emptyplot()
+        }else if(class(temp.IRSL) == "list"){
+          plot_RLum.Data.Curve(temp.IRSL[[length(temp.IRSL)]], par.local = FALSE)
+          warning(
+            "[analyse_SAR.CWOSL()] Multiple IRSL curves detected (IRSL test), show only the last one.",
+            immediate. = TRUE,
+            call. = FALSE
+          )
+        }else{
+          shape::emptyplot()
 
-         }
+        }
 
       }else{
         plot(1, type="n", axes=F, xlab="", ylab="")
